@@ -2,7 +2,7 @@ use Stenciller::Standard;
 use strict;
 use warnings;
 
-our $VERSION = '0.0101'; # VERSION:
+our $VERSION = '0.0200'; # VERSION:
 # PODNAME: Pod::Elemental::Transformer::Stenciller
 # ABSTRACT: Injects content from textfiles transformed with Stenciller
 use Stenciller;
@@ -136,9 +136,24 @@ __END__
 
 Pod::Elemental::Transformer::Stenciller - Injects content from textfiles transformed with Stenciller
 
+
+
+=begin HTML
+
+<p><img src="https://img.shields.io/badge/perl-5.14-brightgreen.svg" alt="Requires Perl 5.14" /> <a href="https://travis-ci.org/Csson/p5-Pod-Elemental-Transformer-Stenciller"><img src="https://api.travis-ci.org/Csson/p5-Pod-Elemental-Transformer-Stenciller.svg?branch=master" alt="Travis status" /></a></p>
+
+=end HTML
+
+
+=begin markdown
+
+![Requires Perl 5.14](https://img.shields.io/badge/perl-5.14-brightgreen.svg) [![Travis status](https://api.travis-ci.org/Csson/p5-Pod-Elemental-Transformer-Stenciller.svg?branch=master)](https://travis-ci.org/Csson/p5-Pod-Elemental-Transformer-Stenciller)
+
+=end markdown
+
 =head1 VERSION
 
-Version 0.0101, released 2015-02-13.
+Version 0.0200, released 2015-11-23.
 
 
 
@@ -159,7 +174,7 @@ This transformer uses a special command in pod files to inject content from else
 
 2. Add a textfile, in C<path/to/stencildir/file-with-stencils.stencil>:
 
-    == stencil { } ==
+    == stencil { to_pod => 1 } ==
 
     Header text
 
@@ -195,37 +210,37 @@ This transformer uses a special command in pod files to inject content from else
 
     :stenciller ToUnparsedText file-with-stencils.stencil
 
-The last line in the Perl module will cause the textfile to be parsed with L<Stenciller>, and then transformed using the L<Stenciller::Plugin::ToUnparsedText> plugin.
+The last line in the Perl module will result in the following:
 
-It would be rendered like this (between I<begin> and I<end>):
+=over 4
 
-I<begin>
+=item *
 
-Header text
+The textfile is parsed with L<Stenciller>
 
-    Input text
+=item *
 
-Between text
+The textfile is then transformed using the L<Stenciller::Plugin::ToUnparsedText> plugin.
 
-    Output text
+=item *
 
-Footer text
+The ':stenciller ...' line in the pod is replaced with the transformed content.
 
-I<end>
+=back
 
 =head2 Pod hash
 
-It is possible to filter stencils by index with an optional hash in the module:
+It is possible to filter stencils by index with an optional hash in the pod:
 
     :stenciller ToUnparsedText 1-test.stencil { stencils => [0, 2..4] }
 
-This will only include the stencils with index 0, 2, 3 and 4 from C<1-test.stencil>.
+This will only include the stencils with index 0, 2, 3 and 4 from C<file-with-stencils.stencil>.
 
 =head2 Stencil hash
 
-This module checks for the C<to_pod> key in the stencil hash. If it is true (or doesn't exist) it is included in the transformation.
+This module checks for the C<to_pod> key in the stencil hash. If it has a true value (or doesn't exist) it is included in the transformation.
 
-However, any stencil excluded by the L</"Pod hash"> is already disregarded. It is probably least confusing to choose one of these places to do all filtering.
+However, any stencil excluded by the L</"Pod hash"> is already disregarded. It is probably least confusing to choose B<one> of these places to do all filtering.
 
 =head1 ATTRIBUTES
 
@@ -278,7 +293,7 @@ Erik Carlsson <info@code301.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Erik Carlsson <info@code301.com>.
+This software is copyright (c) 2015 by Erik Carlsson.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
